/**
 * Менеджер предоставляющий доступ к данным о линках
 *
 * <br>
 * Связанные объекты:
 *
 * - {@link Links.Link} - Модель линка (Топологический линк)
 * - {@link LinkTypes} - Менеджер типов линков (Здесь можно запросить данные по типу линка)
 * - {@link LinkTypes.LinkType} - Модель типа линка (Здесь можно найти атрибуты линка)
 *
 * @group manager
 * @namespace Links
 * @extends manager
 */
function Links() {
    /**
     * Интерфейс доступа к линку
     *
     * Ответ должен быть обработан в промисе,
     *
     * при успехе вернется {@link tools.reference} -> {@link Links.Link}
     *
     * при отмене вернется ошибка {@link Errors.PromiseReject}
     *
     * ```
     * // Пример 1: Как получить линк?
     *
     * // Пример взят для случайного линка
     *
     * // идентификатор линка 64 битный, а нативный number JavaScript'a нет.
     * // поэтому инт генерим из строки
     * var link_id = v2.integer.from_string("-7547783344834658422");
     * var link_ref = null;
     * var link_model = null;
     * ps.pl.links.get(link_id).then(function(ref){
     *     // ref - это ссылка на объект
     *     // метод value возвращает целевой объект. В данном случае дерево  {@type Links.Link}
     *     link_model = ref.value();
     *     link_ref = ref;
     * }, function(err){
     *     // в случае неудачи придет ошибка.
     *     // обычно в ошибке содержится три переменные err - код ошибки, message - краткое описание, sub - если к этому
     *     // привела другая ошибка внутри системы.
     * })
     * ```
     *
     * @public
     * @function get
     * @param {v2.integer} linkId Идентификатор ноды в дереве
     * @returns {tools.promise}
     * @memberof Links
     */
    this.get = function(linkId) {

    };
}
